@@ -46,7 +46,7 @@ class Pipeline:
         for fn_name in serialised:
             try:
                 fn = cls.registered_functions[fn_name]
-            except KeyError as e:
+            except KeyError:
                 raise BaseLunrException(
                     'Cannot load unregistered function '.format(fn_name))
             else:
