@@ -8,7 +8,7 @@ import re
 from lunr.token import Token
 from lunr.utils import as_string
 
-SEPARATOR = r'[\s\-]+'
+SEPARATOR = re.compile(r'[\s\-]+')
 
 
 def Tokenizer(obj, metadata=None):
@@ -43,18 +43,19 @@ def Tokenizer(obj, metadata=None):
     for slice_end in range(length):
         char = string[slice_end]
         slice_length = slice_end - slice_start
-        if re.match(SEPARATOR, char) or slice_end == length - 1:
+        if SEPARATOR.match(char) or slice_end == length - 1:
             if slice_length > 0:
                 sl = slice(
                     slice_start,
                     slice_end if slice_end < length - 1 else None)
 
-                token_metadata = deepcopy(metadata)
+                token_metadata = {}
                 token_metadata['position'] = [
                     slice_start,
                     slice_length
                     if slice_end < length - 1 else slice_length + 1]
                 token_metadata['index'] = len(tokens)
+                token_metadata.update(metadata)
 
                 tokens.append(Token(string[sl], token_metadata))
 
